@@ -10,7 +10,7 @@ bed1 = generateRandomBed(nr = 100)
 bed1 = bed1[sample(nrow(bed1), 20), ]
 bed2 = generateRandomBed(nr = 100)
 bed2 = bed2[sample(nrow(bed2), 20), ]
-circos.par("default.track.height" = 0.1, cell.padding = c(0, 0, 0, 0))
+circos.par("track.height" = 0.1, cell.padding = c(0, 0, 0, 0))
 circos.initializeWithIdeogram()
 
 circos.genomicLink(bed1, bed2, col = sample(1:5, 20, replace = TRUE), border = NA)
