@@ -1,3 +1,6 @@
+
+op = par(no.readonly = TRUE)
+
 library(circlize)
 par(mar = c(1, 1, 1, 1), mfrow = c(1, 2))
 fa = c("d", "f", "e", "c", "g", "b", "a")
@@ -14,3 +17,5 @@ circos.trackPlotRegion(ylim = c(0, 1))
 circos.info(plot = TRUE)
 text(0, 0, "factor(fa,\nlevels = fa)", adj = c(0.5, 0.5), cex = 1.3)
 circos.clear()
+
+par(op)
